
# YMQ

Welcome. This file contains schedule for each day, for each person.

Each person maintains a todo and done list.



# gxu

## DONE:
 - CMake integration, generate C++ stuff in build dir
 - Basic coroutine API

## TODO:
 - Add example usage of this lib to scaler/tests
 - develop the so-called coro_context and their utility
 - write up interfaces(not impl) that uses coroutine


# PUT NAME HERE 

## DONE:

## TODO:

